Changelog
=========


1.1 (2016-06-16)
----------------

- Add post path info to the alternate link urls.
  [zcashero]


1.0 (2016-05-19)
----------------

- Initial release.
  [zcashero]

- Add support for Plone 4.1.x (p.a.m. 1.x), 4.2.x (p.a.m. 1.x), 4.3.x (p.a.m. 2.x) and Plone 5.x (p.a.m. 3.x).
  [tmassman]
